//--------------------------------------------------------------------------
// Jet Pack
// can be used by any armor type
// when activated, gives user a "repair gun" that can be used to
// repair a damaged object or player. If there is no target in
// range for the repair gun, the user is repaired.

datablock AudioProfile(JetPackActivateSound)
{
   filename    = "fx/vehicles/outrider_engine.wav";
   description = ClosestLooping3d;
   preload = true;
};

// Scout
datablock AudioProfile(JetPackThrustSound)
{
   filename    = "fx/vehicles/bomber_boost.wav";
   description = AudioDefaultLooping3d;
   preload = true;
};

datablock ParticleData(JetPackParticle)
{
   dragCoefficient      = 2.75;
   gravityCoefficient   = 1.0;
   inheritedVelFactor   = 0.2;
   constantAcceleration = 0.2;
   lifetimeMS           = 450;
   lifetimeVarianceMS   = 100;
   textureName          = "special/smoke/bigsmoke";
   colors[0]     = "0.66 0.76 0.11 0.5";
   colors[1]     = "0.26 0.16 0.06 0.0";
   sizes[0]      = 0.25;
   sizes[1]      = 1.5;
};

datablock ParticleEmitterData(JetPackEmitter)
{
   ejectionPeriodMS = 3;
   periodVarianceMS = 0;
   ejectionVelocity = 10;
   velocityVariance = 1.0;
   ejectionOffset   = 0.0;
   thetaMin         = 0;
   thetaMax         = 20;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance  = true;
   particles = "JetPackParticle";
};

datablock ParticleEmitterData(JetPackImageEmitter)
{
   ejectionPeriodMS = 3;
   periodVarianceMS = 0;
   ejectionVelocity = 10;
   velocityVariance = 1.0;
   ejectionOffset   = 0.0;
   thetaMin         = 0;
   thetaMax         = 12;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance  = true;
   particles = "JetPackParticle";
};

datablock ShapeBaseImageData(JetPackImage)
{
   shapeFile = "pack_barrel_fusion.dts";
   item = JetPack;
   mountPoint = 1;
   offset = "0 0 0";
   rotation = "0 1 0 180";
   emap = true;

   usesEnergy = true;
   minEnergy = 3;
   
   gun = JetGunImage;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateSequence[1] = "fire";
   stateEmitterTime[1] = 0.1;
   stateEnergyDrain[1] = 8.5;
   stateSound[1] = JetPackActivateSound;
   stateTransitionOnTriggerUp[1] = "Deactivate";

   stateName[2] = "Deactivate";
   stateScript[2] = "onDeactivate";
   stateTransitionOnTimeout[2] = "Idle";   
};

datablock ItemData(JetPack)
{
   className = Pack;
   catagory = "Packs";
   shapeFile = "pack_barrel_fusion.dts";
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 2;
   rotate = true;
   image = "JetPackImage";
   pickUpName = "a jet pack";

   emap = true;
};

datablock ShapeBaseImageData(JetGunImage)
{
   shapeFile = "weapon_targeting.dts";
   offset = "0 0 0";

   usesEnergy = true;
   minEnergy = 3;
   emap = true;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onFire";
   stateSequence[1] = "fire";
   stateSound[1] = JetPackThrustSound;
   stateTransitionOnTriggerUp[1] = "Deactivate";

   stateName[2] = "Deactivate";
   stateScript[2] = "onStop";
   stateTransitionOnTimeout[2] = "Idle";
};

$JetpackMaxSpeed = 52;

function jet(%obj)
{
   if(%obj.getEnergyLevel() > 3)
   {
     if(%obj.jetpacking)
     {
          %obj.disableSwitch = false;
          if(%obj.jetpackTriggered)
          {
               %vec = %obj.getMuzzleVector(0);
               %force = %obj.getDatablock().mass * 3;
               %vx = getWord(%vec, 0);
               %vy = getWord(%vec, 1);
               %vz = getWord(%vec, 2) - 0.001;
               %nVec = %vx@" "@%vy@" "@%vz;
               %newVec = VectorScale(%nVec, %force);
               
               %obj.applyImpulse(%obj.getTransform(), %newVec);

               %vel = %obj.getVelocity();
               %aVel = velToSingle(%vel);
               %vx = getWord(%vel, 0);
               %vy = getWord(%vel, 1);
               %vz = getWord(%vel, 2) + 0.91;

               if(%aVel > $JetpackMaxSpeed)
               {
                    if(%vx > $JetpackMaxSpeed)
                    %vx = $JetpackMaxSpeed;

                    if(%vy > $JetpackMaxSpeed)
                    %vy = $JetpackMaxSpeed;

                    if(%vz > $JetpackMaxSpeed)
                    %vz = $JetpackMaxSpeed + 0.91;
               }

               %newVel = %vx@" "@%vy@" "@%vz;

               %obj.setVelocity(%newVel);
               %obj.useEnergy(4 / 20);
          }
          else
               %obj.setVelocity("0 0 0.91");

          %obj.setHeat(1.0);
          schedule(50, 0, "jet", %obj);
     }
   }
   else
   {
   %obj.setImageTrigger(%slot, false);
   if(%obj.getMountedImage($WeaponSlot).getName() $= "JetGunImage")
      %obj.unmountImage($WeaponSlot);

     %obj.jetpacking = "";
   %obj.disableSwitch = false;
   }
}

function JetPackImage::onUnmount(%data, %obj, %node)
{
   if(%obj.getMountedImage($WeaponSlot))
      if(%obj.getMountedImage($WeaponSlot).getName() $= "JetGunImage")
         %obj.unmountImage($WeaponSlot);

     %obj.jetpacking = "";
   %obj.disableSwitch = false;
}

function JetPackImage::onActivate(%data, %obj, %slot)
{
   %obj.jetpacking = true;
   %obj.disableSwitch = true;
   messageClient(%obj.client, 'MsgJetPackOn', '\c2JetPack is initialising...');
   schedule(1100, 0, "jet", %obj);
//   jet(%obj);

   if(!isObject(%obj.getMountedImage($WeaponSlot)) || %obj.getMountedImage($WeaponSlot).getName() !$= "JetGunImage")
   {
      if(%obj.getMountedImage($WeaponSlot))
         %obj.unmountImage($WeaponSlot);
      %obj.setArmThread(look);
      %obj.mountImage(JetGunImage, $WeaponSlot);
      commandToClient(%obj.client, 'setRepairReticle');  // hjejeje
   }
}

function JetPackImage::onDeactivate(%data, %obj, %slot)
{
   %obj.setImageTrigger(%slot, false);
   if(%obj.getMountedImage($WeaponSlot).getName() $= "JetGunImage")
      %obj.unmountImage($WeaponSlot);

     %obj.jetpacking = "";
   %obj.disableSwitch = false;
}

function JetGunImage::onMount(%this,%obj,%slot)
{
   %obj.setImageAmmo(%slot,true);
   %obj.jetpacking = true;
   %obj.disableSwitch = true;
}

function JetGunImage::onFire(%this,%obj,%slot)
{
   %obj.jetpackTriggered = true;
}

function JetGunImage::onStop(%this,%obj,%slot)
{
   %obj.jetpackTriggered = "";
}

function JetGunImage::onUnmount(%this,%obj,%slot)
{
   %obj.setImageTrigger(%slot, false);
   %obj.setImageTrigger($BackpackSlot, false);
   %obj.jetpackTriggered = "";
   %obj.jetpacking = "";
   %obj.disableSwitch = false;
}

function JetPack::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}
