//-------------------------------------------
// PWT Launcher (Pulse Wave Torpedo) launcher
//------------------------------

datablock AudioProfile(PWTFireSound)
{
   filename    = "fx/powered/turret_missile_fire.wav";
   description = AudioDefault3d;
   preload = true;
   effect = MortarFireEffect;
};

datablock AudioProfile(PWTProjectileSound)
{
   filename    = "fx/armor/bubbletrail.wav";
   description = ProjectileLooping3d;
   preload = true;
};

datablock ExplosionData(PWTExplosion)
{
   soundProfile   = PBWExpSound;
   particleEmitter = VehicleBombExplosionEmitter;
   particleDensity = 250;
   particleRadius = 5;
   faceViewer = true;

   emitter[0] = "DiscExplosionBubbleEmitter";
   shockwave = VehicleBombShockwave;
   shockwaveOnTerrain = true;

   subExplosion[0] = VehicleBombSubExplosion1;
   subExplosion[1] = VehicleBombSubExplosion2;
   subExplosion[2] = VehicleBombSubExplosion3;

   shakeCamera = true;
   camShakeFreq = "5.0 7.0 5.0";
   camShakeAmp = "80.0 80.0 80.0";
   camShakeDuration = 1.0;
   camShakeRadius = 30.0;
};

//--------------------------------------------------------------------------
// Projectile
//--------------------------------------
datablock SeekerProjectileData(PWTorpedo)
{
   casingShapeName     = "weapon_missile_casement.dts";
   projectileShapeName = "mortar_projectile.dts";
   hasDamageRadius     = true;
   indirectDamage      = 2.0;
   damageRadius        = 30.0;
   radiusDamageType    = $DamageType::PWT;
   kickBackStrength    = 5000;
   explosion           = "PWTExplosion";
   underwaterExplosion = "PWTExplosion";
   splash              = MissileSplash;
   velInheritFactor    = 1.0;    // to compensate for slow starting velocity, this value
                                 // is cranked up to full so the missile doesn't start
                                 // out behind the player when the player is moving
                                 // very quickly - bramage

   baseEmitter         = MortarBubbleEmitter;
   bubbleEmitTime      = 1.0;


   lifetimeMS          = 6000;
   muzzleVelocity      = 10.0;
   maxVelocity         = 40.0;
   turningSpeed        = 1.0;
   acceleration        = 10.0;

   proximityRadius     = 0;

   terrainAvoidanceSpeed         = 0;
   terrainScanAhead              = 0;
   terrainHeightFail             = 0;
   terrainAvoidanceRadius        = 0;
   
   flareDistance = 200;
   flareAngle    = 30;

   sound = PWTProjectileSound;

   hasLight    = true;
   lightRadius = 5.0;
   lightColor  = "0.2 0.05 0";

   useFlechette = true;
   flechetteDelayMs = 100;
   casingDeb = FlechetteDebris;

   explodeOnWaterImpact = false;
};



//--------------------------------------------------------------------------
// Ammo
//--------------------------------------

datablock ItemData(PWTLauncherAmmo)
{
   className = Ammo;
   catagory = "Ammo";
   shapeFile = "ammo_missile.dts";
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 2;
	pickUpName = "some pw torpedoes";
};

//--------------------------------------------------------------------------
// Weapon
//--------------------------------------
datablock ItemData(PWTLauncher)
{
   className = Weapon;
   catagory = "Spawn Items";
   shapeFile = "weapon_mortar.dts";
   image = PWTLauncherImage;
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 2;
	pickUpName = "a PWT launcher";

   emap = true;
};

datablock ShapeBaseImageData(PWTLauncherImage)
{
   className = WeaponImage;
   shapeFile = "weapon_mortar.dts";
   item = PWTLauncher;
   ammo = PWTLauncherAmmo;
   offset = "0 0 0";
   emap = true;

   projectile = PWTorpedo;
   projectileType = SeekerProjectile;

   stateName[0]                     = "Activate";
   stateTransitionOnTimeout[0]      = "ActivateReady";
   stateTimeoutValue[0]             = 0.5;
   stateSequence[0]                 = "Activate";
   stateSound[0]                    = MissileSwitchSound;

   stateName[1]                     = "ActivateReady";
   stateTransitionOnLoaded[1]       = "Ready";
   stateTransitionOnNoAmmo[1]       = "NoAmmo";

   stateName[2]                     = "Ready";
   stateTransitionOnNoAmmo[2]       = "NoAmmo";
   stateTransitionOnTriggerDown[2]  = "WetFire";

   stateName[3]                     = "WetFire";
   stateTransitionOnTimeout[3]      = "Reload";
   stateTimeoutValue[3]             = 0.5;
   stateFire[3]                     = true;
   stateRecoil[3]                   = LightRecoil;
   stateAllowImageChange[3]         = false;
   stateSequence[3]                 = "Fire";
   stateScript[3]                   = "onFire";
   stateSound[3]                    = PWTFireSound;

   stateName[4]                     = "Reload";
   stateTransitionOnNoAmmo[4]       = "NoAmmo";
   stateTransitionOnTimeout[4]      = "Ready";
   stateTimeoutValue[4]             = 3.0;
   stateAllowImageChange[4]         = false;
   stateSequence[4]                 = "Reload";
   stateSound[4]                    = MissileReloadSound;

   stateName[5]                     = "NoAmmo";
   stateTransitionOnAmmo[5]         = "Reload";
   stateSequence[5]                 = "NoAmmo";
   stateTransitionOnTriggerDown[5]  = "DryFire";

   stateName[6]                     = "DryFire";
   stateSound[6]                    = MortarDryFireSound;
   stateTimeoutValue[6]             = 1.0;
   stateTransitionOnTimeout[6]      = "ActivateReady";
   
   stateName[7]                     = "CheckWet";
   stateTransitionOnWet[7]          = "WetFire";
   stateTransitionOnNotWet[7]       = "Fire";
   
   stateName[8]                     = "Fire";
   stateTransitionOnNoAmmo[8]       = "NoAmmo";
   stateTransitionOnTimeout[8]      = "Reload";
   stateSound[8]                    = MissileDryFireSound;
   stateTimeoutValue[8]             = 0.5;
};
