//--------------------------------------
// Ripper
//--------------------------------------

//--------------------------------------------------------------------------
// Sounds
//--------------------------------------
datablock AudioProfile(RipperLoopSound)
{
   filename    = "fx/misc/nexus_idle.wav";
   description = ClosestLooping3d;
   effect = DiscIdleEffect;
};


datablock AudioProfile(RipperFireSound)
{
   filename    = "fx/powered/nexus_deny.wav";
   description = AudioDefault3d;
   preload = true;
   effect = DiscFireEffect;
};

datablock AudioProfile(RipperProjectileSound)
{
   filename    = "fx/environment/rain_hard_2.wav";
   description = ProjectileLooping3d;
   preload = true;
};

//--------------------------------------------------------------------------
// Projectile
//--------------------------------------
datablock LinearProjectileData(RipperProjectileOld)
{
   projectileShapeName = "disc.dts";
   emitterDelay        = -1;
   directDamage        = 0.45;
   directDamageType    = $DamageType::Ripper;
   hasDamageRadius     = true;
   indirectDamage      = 0.1;
   damageRadius        = 5.0;
   kickBackStrength    = 0.0;
   radiusDamageType    = $DamageType::Ripper;

   sound 			   = RipperProjectileSound;
   explosion           = "PlasmaBoltExplosion";
   underwaterExplosion = "UnderwaterHandGrenadeExplosion";
   splash              = DiscSplash;

   dryVelocity       = 2000;
   wetVelocity       = 1900;    // uw advantage :)
   velInheritFactor  = 0.5;
   fizzleTimeMS      = 5000;
   lifetimeMS        = 5000;
   explodeOnDeath    = false;
   reflectOnWaterImpactAngle = 0.0;
   explodeOnWaterImpact      = false;
   deflectionOnWaterImpact   = 0.0;
   fizzleUnderwaterMS        = 5000;

   activateDelayMS = 50;

   hasLight    = false;
};

datablock EnergyProjectileData(RipperProjectile)
{
   projectileShapeName = "disc.dts";
   emitterDelay        = -1;
   directDamage        = 0.375;
   directDamageType    = $DamageType::Ripper;
   kickBackStrength    = 250;

   grenadeElasticity = 0.998;
   grenadeFriction   = 0.0;
   armingDelayMS     = 47;

   sound 			   = RipperProjectileSound;
   explosion           = "SniperExplosion";
   underwaterExplosion = "SniperExplosion";
   splash              = DiscSplash;
   velInheritFactor    = 0.5;
   muzzleVelocity    = 2000;
   drag = 0.05;
   gravityMod        = 0.0;

   dryVelocity       = 2000;
   wetVelocity       = 2000;
   explodeOnDeath    = true;
   reflectOnWaterImpactAngle = 0.0;
   explodeOnWaterImpact      = false;
   deflectionOnWaterImpact   = 0.0;
   fizzleUnderwaterMS        = 5000;

   hasLight    = false;

   scale = "1.2 1.2 1.2";
   crossViewAng = 0.99;
   crossSize = 0.01;

   lifetimeMS     = 5000;
   blurLifetime   = 3.2;
   blurWidth      = 0.1;
   blurColor = "0.0 0.3 0.85 0.75";

   texture[0] = "special/ELFLightning";
   texture[1] = "special/ELFLightning";
};


//--------------------------------------------------------------------------
// Ammo
//--------------------------------------

datablock ItemData(RipperAmmo)
{
   className = Ammo;
   catagory = "Ammo";
   shapeFile = "ammo_disc.dts";
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 2;
	pickUpName = "some ripper discs";
};

//--------------------------------------------------------------------------
// Weapon
//--------------------------------------
datablock ItemData(Ripper)
{
   className = Weapon;
   catagory = "Spawn Items";
   shapeFile = "weapon_disc.dts";
   image = RipperImage;
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 2;
	pickUpName = "a ripper";
   emap = true;
};

datablock ShapeBaseImageData(RipperImage)
{
   className = WeaponImage;
   shapeFile = "weapon_disc.dts";
   item = Ripper;
   ammo = RipperAmmo;
   offset = "0 0 0";
   emap = true;

   projectile = RipperProjectile;
   projectileType = EnergyProjectile;

   // State Data
   stateName[0]                     = "Preactivate";
   stateTransitionOnLoaded[0]       = "Activate";
   stateTransitionOnNoAmmo[0]       = "NoAmmo";

   stateName[1]                     = "Activate";
   stateTransitionOnTimeout[1]      = "Ready";
   stateTimeoutValue[1]             = 0.5;
   stateSequence[1]                 = "Activated";
   stateSound[1]                    = DiscSwitchSound;

   stateName[2]                     = "Ready";
   stateTransitionOnNoAmmo[2]       = "NoAmmo";
   stateTransitionOnTriggerDown[2]  = "CheckWet";
   stateSequence[2]                 = "DiscSpin";
   stateSound[2]                    = RipperLoopSound;

   stateName[3]                     = "Fire";
   stateTransitionOnTimeout[3]      = "Reload";
   stateTimeoutValue[3]             = 0.275;
   stateFire[3]                     = true;
   stateRecoil[3]                   = LightRecoil;
   stateAllowImageChange[3]         = false;
   stateSequence[3]                 = "Fire";
   stateScript[3]                   = "onFire";
   stateSound[3]                    = RipperFireSound;

   stateName[4]                     = "Reload";
   stateTransitionOnNoAmmo[4]       = "NoAmmo";
   stateTransitionOnTimeout[4]      = "Ready";
   stateTimeoutValue[4]             = 0.15;
   stateAllowImageChange[4]         = false;
   stateSequence[4]                 = "Reload";
   stateSound[4]                    = DiscReloadSound;

   stateName[5]                     = "NoAmmo";
   stateTransitionOnAmmo[5]         = "Reload";
   stateSequence[5]                 = "NoAmmo";
   stateTransitionOnTriggerDown[5]  = "DryFire";

   stateName[6]                     = "DryFire";
   stateSound[6]                    = DiscDryFireSound;
   stateTimeoutValue[6]             = 1.0;
   stateTransitionOnTimeout[6]      = "NoAmmo";

   stateName[7]       = "WetFire";
   stateSound[7]      = DiscDryFireSound;
   stateSequence[7]                 = "Fire";
   stateTimeoutValue[7]        = 1.5;
   stateTransitionOnTimeout[7] = "Ready";

   stateName[8]               = "CheckWet";
   stateTransitionOnWet[8]    = "WetFire";
   stateTransitionOnNotWet[8] = "Fire";

};
